Use a hierarchical Bayesian mixture model with four Gaussian components. Variances are scaled by 0, 0.0001 , 0.001 , and 0.01 .
Source:R/regularizedRegressionWrappers.R
bayesRWeights.RdUse a hierarchical Bayesian mixture model with four Gaussian components. Variances are scaled by 0, 0.0001 , 0.001 , and 0.01 .