Function to perform TWAS analysis for across multiple contexts. This function peforms TWAS analysis for multiple contexts for imputable genes within an LD region and summarize the twas results.
Source:R/twas.R
build_twas_score_row.RdFunction to perform TWAS analysis for across multiple contexts. This function peforms TWAS analysis for multiple contexts for imputable genes within an LD region and summarize the twas results.
Value
A list of list containing twas result table and formatted TWAS data compatible with ctwas_sumstats() function.
twas_table A dataframe of twas results summary is generated for each gene-contexts-method pair of all methods for imputable genes.
twas_data A list of list containing formatted TWAS data.