This function performing filters on X variants based on Y subjects for TWAS analysis. This function checks whether the absence (NA) of certain subjects would lead to monomorphic in some variants in X after removing of these subjects data from X.
Source:R/misc.R
filter_X_with_Y.RdThis function performing filters on X variants based on Y subjects for TWAS analysis. This function checks whether the absence (NA) of certain subjects would lead to monomorphic in some variants in X after removing of these subjects data from X.