Skip to contents

Utility function to specify the path to access the target list item in a nested list, especially when some list layers in between are dynamic or uncertain.

Usage

find_data(
  x,
  depth_obj,
  show_path = FALSE,
  rm_null = TRUE,
  rm_dup = FALSE,
  docall = c,
  last_obj = NULL
)