Skip to contents

This function constructs a list that mimics the structure of SuSiE output sets from a fSuSiE object. It includes credible sets (cs) with their names, a purity dataframe, coverage information, and the requested coverage level.

Usage

fsusie_get_cs(fSuSiE.obj, X, requested_coverage = 0.95)

Arguments

fSuSiE.obj

A fSuSiE object containing the results from a fSuSiE analysis. expected to at least have 'cs' and 'alpha' components.

requested_coverage

A numeric value specifying the desired coverage level for the credible sets. This is purely for record purpose so should be manually ensured that it correctly reflect the actual coverage used. Defaults to 0.95.

Value

A list containing named credible sets (cs), a dataframe of purity metrics (min.abs.corr, mean.abs.corr, median.abs.corr), an index of credible sets (cs_index), coverage values for each set, and the requested coverage level. Similar to the SuSiE set output