Wrapper for fsusie Function with Automatic Post-Processing
Source:R/fsusie_wrapper.R
fsusie_wrapper.RdThis function serves as a wrapper for the fsusie function, facilitating automatic post-processing such as removing dummy credible sets (cs) that don't meet the minimum purity threshold and calculating correlations for the remaining cs. The function parameters are identical to those of the fSuSiE function.
Arguments
- X
Residual genotype matrix.
- Y
Response phenotype matrix.
- pos
Genomics position of phenotypes, used for specifying the wavelet model.
- L
The maximum number of the credible set.
- prior
method to generate the prior.
- max_SNP_EM
maximum number of SNP used for learning the prior.
- cov_lev
Coverage level for the credible sets.
- min_purity
Minimum purity threshold for credible sets to be retained.
- max_scale
numeric, define the maximum of wavelet coefficients used in the analysis (2^max_scale). Set 10 true by default.
- ...
Additional arguments passed to the fsusie function.