Extract the LD correlation matrix from an LDData
object. If only a genotype handle is available, recomputes R from
genotypes on the fly.
Extract the LD correlation matrix from an LDData
object. If only a genotype handle is available, recomputes R from
genotypes on the fly.