Whether the LD reference panel is from the same cohort as the GWAS (affects bias correction).
Examples
data(ldEigenExample)
getInSample(ldEigenExample)
#> [1] FALSE
Whether the LD reference panel is from the same cohort as the GWAS (affects bias correction).
data(ldEigenExample)
getInSample(ldEigenExample)
#> [1] FALSE