Return the standard error of the regression intercept carried
by an H2Estimate.
Examples
data(h2EstimateExample)
getInterceptSe(h2EstimateExample)
#> [1] 0.02
Return the standard error of the regression intercept carried
by an H2Estimate.
data(h2EstimateExample)
getInterceptSe(h2EstimateExample)
#> [1] 0.02