Get Method Names
Source:R/AllGenerics.R, R/AllClasses.R, R/CtwasResult.R, and 2 more
getMethodNames.RdExtract the method name(s) an object was produced with: one per entry for a collection, a single name for one estimate.
R/AllGenerics.R, R/AllClasses.R, R/CtwasResult.R, and 2 more
getMethodNames.RdExtract the method name(s) an object was produced with: one per entry for a collection, a single name for one estimate.