Return the number of variants the heritability estimate was computed over.
Examples
data(h2EstimateExample)
getNSnps(h2EstimateExample)
#> [1] 100
Return the number of variants the heritability estimate was computed over.
data(h2EstimateExample)
getNSnps(h2EstimateExample)
#> [1] 100