Skip to contents

Extract variant ID vector from an object that carries one (e.g., LdData, FineMappingEntry, TwasWeightsEntry) or from one entry of a collection class selected by its identity tuple.

Usage

getVariantIds(x, ...)

# S4 method for class 'FineMappingResultBase'
getVariantIds(
  x,
  study = NULL,
  context = NULL,
  trait = NULL,
  method = NULL,
  region = NULL,
  ...
)

# S4 method for class 'FineMappingEntry'
getVariantIds(x, ...)

# S4 method for class 'LdData'
getVariantIds(x, ...)

# S4 method for class 'TwasWeightsEntry'
getVariantIds(x, ...)

# S4 method for class 'TwasWeights'
getVariantIds(
  x,
  study = NULL,
  context = NULL,
  trait = NULL,
  method = NULL,
  ...
)

Arguments

x

The object.

...

Class-specific selection arguments.

Value

Character vector of variant IDs.