Utility function to format meta data dataframe for cTWAS analyses
Source:R/ctwas_wrapper.R
get_ctwas_meta_data.RdUtility function to format meta data dataframe for cTWAS analyses
R/ctwas_wrapper.R
get_ctwas_meta_data.RdUtility function to format meta data dataframe for cTWAS analyses