Detect whether each annotation is binary or continuous
Source:R/sldsc_wrapper.R
is_binary_sldsc_annot.RdInspects each annotation column and returns whether its values lie in {0, 1} (binary) or take other values (continuous).
R/sldsc_wrapper.R
is_binary_sldsc_annot.RdInspects each annotation column and returns whether its values lie in {0, 1} (binary) or take other values (continuous).