Convert a log-Bayes-factor matrix to Single Effect PIPs
Source:R/fineMappingWrappers.R
lbfToAlpha.RdApplies the 'lbfToAlphaVector' function row-wise to a matrix of log Bayes factors to convert them to Single Effect PIP values.
R/fineMappingWrappers.R
lbfToAlpha.RdApplies the 'lbfToAlphaVector' function row-wise to a matrix of log Bayes factors to convert them to Single Effect PIP values.