Skip to contents

This function fits the `mr.ash` model (adaptive shrinkage regression) to estimate weights for a given set of predictors and response. It uses optional prior standard deviation initialization and can accept custom initial beta values.

Usage

mrash_weights(X, y, init_prior_sd = TRUE, ...)

Examples

wgt.mr.ash <- mrash_weights(eqtl$X, eqtl$y_res, beta.init = lasso_weights(X, y))
#> Error: object 'X' not found