Skip to contents

Perform udr Analysis on Multigene Data

Usage

multigene_udr(
  combined_susie_list,
  coverage,
  independent_variant_list,
  n_random,
  n_null,
  seed,
  exclude_condition = NULL
)

Arguments

combined_susie_list

A list containing the combined SuSiE and summary statistics results.

coverage

A numeric vector representing the coverage values.

independent_variant_list

A list of independent variants to be used as a filter.

n_random

An integer specifying the number of random samples to generate.

n_null

An integer specifying the number of null samples to generate.

seed

An integer specifying the seed for random number generation.

exclude_condition

A character vector specifying conditions to be excluded from the analysis. Defaults to NULL.

Value

A list containing the results of the prior, or NULL if conditions are not met.