Skip to contents

Reads a GWAS summary statistics file in the format expected by the DENTIST C++ binary and returns it as an R data frame with z-scores computed.

Usage

read_dentist_sumstat(gwas_summary)

Arguments

gwas_summary

Path to summary statistics file (tab/space-separated, 8 columns: SNP A1 A2 freq beta se p N). May be gzipped.

Value

A data frame with columns: SNP, A1, A2, freq, beta, se, p, N, z.