Skip to contents

Function to select variants for ctwas weights input

Usage

trim_ctwas_variants(
  region_data,
  twas_weight_cutoff = 1e-05,
  cs_min_cor = 0.8,
  min_pip_cutoff = 0.1,
  max_num_variants = 1000
)

Arguments

region_data

A list of list containing weights list and snp_info list data for multiple genes/events within a single LD block region.

export_twas_weight_db

A list of list of fine-mapping result data formatted by generate_twas_db function.

region_block

A string for region information for region_weights, consisted of chromosome number, star and end position of LD block conneced with "_".