This function adjusts the SuSiE weights based on a set of intersected variants.
It subsets various components like lbf_matrix, mu, and scale factors based on these variants.
Usage
adjust_susie_weights(
twas_weights_results,
keep_variants,
allele_qc = TRUE,
variable_name_obj = c("susie_results", context, "variant_names"),
susie_obj = c("susie_results", context, "susie_result_trimmed"),
twas_weights_table = c("weights", context),
combined_LD_variants,
match_min_prop = 0.2
)
Arguments
- keep_variants
Vector of variant names to keep.
- allele_qc
Optional
- weight_db_file
A RDS file containing TWAS weights.
- condition
specific condition.
Value
A list of adjusted xQTL coefficients and remained variants ids