Multi-trait colocalization analysis pipeline
Source:R/colocboost_pipeline.R
colocboost_analysis_pipeline.RdThis function perform a multi-trait colocalization using ColocBoost
Usage
colocboost_analysis_pipeline(
region_data,
focal_trait = NULL,
event_filters = NULL,
xqtl_coloc = TRUE,
joint_gwas = FALSE,
separate_gwas = FALSE,
maf_cutoff = 5e-04,
pip_cutoff_to_skip_ind = 0,
remove_indels = FALSE,
pip_cutoff_to_skip_sumstat = 0,
qc_method = c("dentist", "slalom"),
impute = TRUE,
impute_opts = list(rcond = 0.01, R2_threshold = 0.6, minimum_ld = 5, lamb = 0.01),
...
)Arguments
- region_data
A region data loaded from
load_regional_data.- focal_trait
Name of trait if perform focaled ColocBoost
- event_filters
A list of pattern for filtering events based on context names. Example: for sQTL, list(type_pattern = ".*clu_(\d+_[+-?]).*",valid_pattern = "clu_(\d+_[+-?]):PR:",exclude_pattern = "clu_(\d+_[+-?]):IN:")
- maf_cutoff
A scalar to remove variants with maf < maf_cutoff, dafault is 0.005.
- pip_cutoff_to_skip_ind
A vector of cutoff values for skipping analysis based on PIP values for each context. Default is 0.
- pip_cutoff_to_skip_sumstat
A vector of cutoff values for skipping analysis based on PIP values for each sumstat Default is 0.
- qc_method
Quality control method to use. Options are "dentist" or "slalom" (default: "dentist").
- impute
Logical; if TRUE, performs imputation for outliers identified in the analysis (default: TRUE).
- impute_opts
A list of imputation options including rcond, R2_threshold, and minimum_ld (default: list(rcond = 0.01, R2_threshold = 0.6, minimum_ld = 5)).
Value
A list containing the individual_data and sumstat_data after QC: individual_data contains the following components if exist
Y: A list of residualized phenotype values for all tasks.
X: A list of residualized genotype matrices all tasks.
sumstat_data contains the following components if exist
sumstats: A list of summary statistics f or the matched LD_info, each sublist contains sumstats, n, var_y from
load_rss_data.LD_info: A list of LD information, each sublist contains combined_LD_variants, combined_LD_matrix, ref_panel
load_LD_matrix.