Utility function to specify the path to access the target list item in a nested list, especially when some list layers in between are dynamic or uncertain.
Source:R/misc.R
find_data.RdUtility function to specify the path to access the target list item in a nested list, especially when some list layers in between are dynamic or uncertain.