@title Create Sets Similar to SuSiE Output from fSuSiE Object
Source:R/fsusie_wrapper.R
fsusie_get_cs.RdThis function constructs a list that mimics the structure of SuSiE output sets from a fSuSiE object. It includes credible sets (cs) with their names, a purity dataframe, coverage information, and the requested coverage level.
Arguments
- fSuSiE.obj
A fSuSiE object containing the results from a fSuSiE analysis. expected to at least have 'cs' and 'alpha' components.
- requested_coverage
A numeric value specifying the desired coverage level for the credible sets. This is purely for record purpose so should be manually ensured that it correctly reflect the actual coverage used. Defaults to 0.95.