Get Context Names
Source:R/AllGenerics.R, R/CtwasResult.R, R/GwasFineMappingResult.R, and 4 more
getContexts.RdReturn the names of all contexts carried by an object
(e.g., the keys of the phenotypes list on a QtlDataset,
or the unique context values of a QtlSumStats).
Usage
getContexts(x)
# S4 method for class 'CtwasResult'
getContexts(x)
# S4 method for class 'GwasFineMappingResult'
getContexts(x)
# S4 method for class 'QtlDataset'
getContexts(x)
# S4 method for class 'QtlFineMappingResult'
getContexts(x)
# S4 method for class 'QtlSumStats'
getContexts(x)
# S4 method for class 'TwasWeights'
getContexts(x)