Skip to contents

Extract phenotype data from an object that carries it. For a QtlDataset, the user can optionally select specific contexts, traits, or a region (see method documentation for the per-class selection arguments).

Usage

getPhenotypes(x, ...)

# S4 method for class 'QtlDataset'
getPhenotypes(
  x,
  contexts,
  traitId = NULL,
  region = NULL,
  naAction = c("keep", "drop", "impute"),
  outlierAction = c("keep", "drop"),
  outlierPvalThreshold = 0.001,
  ...
)

Arguments

x

The object to extract from.

...

Class-specific selection arguments (e.g., contexts, traitId, region).

Value

A named list of phenotype matrices or SummarizedExperiment objects.