Skip to contents

Applies the 'lbfToAlphaVector' function row-wise to a matrix of log Bayes factors to convert them to Single Effect PIP values.

Usage

lbfToAlpha(lbf)

Arguments

lbf

Matrix of log Bayes factors.

Value

A matrix of alpha values with the same dimensions as the input LBF matrix.

Examples

lbfMatrix <- matrix(c(-0.5, 1.2, 0.3, 0.7, -1.1, 0.4), nrow = 2)
alphaMatrix <- lbfToAlpha(lbfMatrix)
print(alphaMatrix)
#>           [,1]      [,2]      [,3]
#> [1,] 0.2649461 0.5896484 0.1454055
#> [2,] 0.4864145 0.2950253 0.2185601