Applies the 'lbf_to_alpha_vector' function row-wise to a matrix of log Bayes factors to convert them to Single Effect PIP values.
Source:R/susie_wrapper.R
lbf_to_alpha.RdApplies the 'lbf_to_alpha_vector' function row-wise to a matrix of log Bayes factors to convert them to Single Effect PIP values.