Skip to contents

By default, plink usage dosage of the *major* allele, since "effect allele" A1 is usually the minor allele and the code "1" refers to the "other allele" A2, so that "11" is A2/A2 or major/major. We always use effect allele dosage, to be more consistent with the minor allele based convention ie, plink –recodeA which used minor allele dosage by default.

Usage

load_genotype_region(
  genotype,
  region = NULL,
  keep_indel = TRUE,
  keep_variants_path = NULL
)

Arguments

genotype

Path to the genotype data file (without extension).

region

The target region in the format "chr:start-end".

keep_indel

Whether to keep indel SNPs.

Value

A vector of SNP IDs in the specified region.