Load genotype data for a specific region using vroom for efficiency
Source:R/file_utils.R
load_genotype_region.RdBy default, plink usage dosage of the *major* allele, since "effect allele" A1 is usually the minor allele and the code "1" refers to the "other allele" A2, so that "11" is A2/A2 or major/major. We always use effect allele dosage, to be more consistent with the minor allele based convention ie, plink –recodeA which used minor allele dosage by default.