Load and filter tabular data with optional region subsetting
Source:R/file_utils.R
load_tsv_region.RdThis function loads summary statistics data from tabular files (TSV, TXT). For compressed (.gz) and tabix-indexed files, it can subset data by genomic region. Additionally, it can filter results by a specified target value in a designated column.
Usage
load_tsv_region(
file_path,
region = NULL,
extract_region_name = NULL,
region_name_col = NULL
)Arguments
- file_path
Path to the summary statistics file.
- region
Genomic region for subsetting tabix-indexed files. Format: chr:start-end (e.g., "9:10000-50000").
- extract_region_name
Value to filter for in the specified filter column.
- region_name_col
Index of the column to apply the extract_region_name against.