Skip to contents

This function fits the `mr.ash` model (adaptive shrinkage regression) to estimate weights for a given set of predictors and response. It uses optional prior standard deviation initialization and can accept custom initial beta values.

Usage

mrashWeights(X, y, initPriorSd = TRUE, retainFit = FALSE, ...)

Examples

wgt.mr.ash <- mrashWeights(eqtl$X, eqtl$y_res, beta.init = lassoWeights(X, y))
#> Error: object 'eqtl' not found