This function fits the `mr.ash` model (adaptive shrinkage regression) to estimate weights for a given set of predictors and response. It uses optional prior standard deviation initialization and can accept custom initial beta values.
This function fits the `mr.ash` model (adaptive shrinkage regression) to estimate weights for a given set of predictors and response. It uses optional prior standard deviation initialization and can accept custom initial beta values.