Skip to contents

The first field is treated as the chromosome and kept as a normalized string (via canonChrom) so X/Y/MT survive; the remaining fields are genomic positions and are returned as integers.

Usage

regionToDf(ldRegionId, colnames = c("chrom", "start", "end"))

Arguments

ldRegionId

A string of region in the format of chrom_start_end.