Skip to contents

Performs Approximate Bayesian Factor (ABF) analysis, identifies credible sets, and annotates lead variants based on fine-mapping results. It computes p-values from z-scores assuming a two-sided standard normal distribution.

Usage

slalom(
  zScore,
  R = NULL,
  X = NULL,
  standard_error = rep(1, length(zScore)),
  abf_prior_variance = 0.04,
  nlog10p_dentist_s_threshold = 4,
  r2_threshold = 0.6,
  lead_variant_choice = "pvalue"
)

Arguments

zScore

Numeric vector of z-scores corresponding to each variant.

R

Square LD correlation matrix. Provide either R or X.

X

Genotype matrix (samples x SNPs). If provided, LD is computed via compute_LD(X).

standard_error

Optional numeric vector of standard errors corresponding to each z-score. If not provided, a default value of 1 is assumed for all variants.

abf_prior_variance

Numeric, the prior effect size variance for ABF calculations. Default is 0.04.

nlog10p_dentist_s_threshold

Numeric, the -log10 DENTIST-S P value threshold for identifying outlier variants for prediction. Default is 4.0.

r2_threshold

Numeric, the r2 threshold for DENTIST-S outlier variants for prediction. Default is 0.6.

lead_variant_choice

Character, method to choose the lead variant, either "pvalue" or "abf", with default "pvalue".

Value

A list containing the annotated LD matrix with ABF results, credible sets, lead variant, and DENTIST-S statistics; and a summary dataframe with aggregate statistics.

Details

Provide either an LD correlation matrix R or a genotype matrix X (from which LD is derived automatically via compute_LD).

See also

dentist_single_window, resolve_LD_input

Examples

results <- slalom(zScore, R = R, standard_error = standard_error)
#> Error: object 'R' not found