Wrapper Function for SuSiE RSS with Dynamic L Adjustment
Source:R/susie_wrapper.R
susie_rss_wrapper.RdThis function performs SuSiE RSS analysis, dynamically adjusting the number of causal configurations (L) and applying quality control and imputation as necessary. It includes the total phenotypic variance `var_y` as one of its parameters to align with the `susie_rss` function's interface.
Usage
susie_rss_wrapper(
z,
R,
n = NULL,
var_y = NULL,
L = 10,
max_L = 30,
l_step = 5,
zR_discrepancy_correction = FALSE,
coverage = 0.95,
...
)Arguments
- z
Z score vector.
- R
LD matrix.
- n
Sample size; if NULL, certain functionalities that require sample size will be skipped.
- var_y
Total phenotypic variance.
- L
Initial number of causal configurations to consider.
- max_L
Maximum number of causal configurations to consider.
- l_step
Step size for increasing L when the limit is reached.
- zR_discrepancy_correction
Logical indicating if z-score and R matrix discrepancy correction should be performed.
- ...
Extra parameters to pass to the susie_rss function.